pub fn load_certificates() -> Result<Vec<Certificate>, Error>Expand description
Loads a Certificate from the backend, for each signing key configured in the Signstar
configuration.
Note
Access to each signing key’s certificate is established using backend users that lack permission to use the signing key for signing.
Errors
Returns an error if
- loading the Signstar configuration fails
- getting the Unix user of the current process fails
- no backend user(s) are mapped to the currently calling system user
- no backend credentials can be loaded for the currently calling system user
- loading encounters errors
- certificate retrieval of a signing key fails